==> currents-api-types-0.0.29.tgz: package/channel/parsers.ts <==
import { z } from 'zod';
import { firestoreListParamsParser } from '../common/parsers/queryParams';
import { nullableBoolParser, nullableStringParser, nullableUrlStringParser } from '../common/parsers';
import { stripeProductIdParser } from '../stripe/parsers';
import { firebaseBlogIdParser } from '../blog/parsers.id';
import { firebaseCollectiveIdParser } from '../collective/parsers.id';
import { firebaseAdminIdParser } from '../collective/parsers.admin';
import { BLOG, CHANNEL_TYPES, COLLECTIVE, MIXSPACE } from './constants';
import { mixspaceIdParser } from '../mixspace/parsers.id';

export const channelListParamsParser = firestoreListParamsParser
  .merge(
    z
      .object({
        adminId: firebaseAdminIdParser,
      })
      .partial()
  )
  .strict();
export type ChannelListParams = z.infer<typeof channelListParamsParser>;
export const channelIdParser = firebaseBlogIdParser.or(firebaseCollectiveIdParser).or(mixspaceIdParser);

// asserted in types
export const channelCompositeIdParser = z.discriminatedUnion('type', [
  z.object({
    type: z.literal(BLOG),
    id: firebaseBlogIdParser,
  }),
  z.object({
    type: z.literal(COLLECTIVE),
    id: firebaseCollectiveIdParser,
  }),
  z.object({
    type: z.literal(MIXSPACE),
    id: mixspaceIdParser,
  }),
]);

export const channelGetOneParamsParser = z.object({
  id: channelIdParser,
});
export type ChannelGetOneParams = z.infer<typeof channelGetOneParamsParser>;
export const blogIdTraitParser = z.object({
  id: firebaseBlogIdParser,
});
export const collectiveChannelCreateInput = z.object({
  MV: nullableStringParser,
  admins: z.array(firebaseBlogIdParser),
  alias: nullableStringParser,
  blogs: z.array(firebaseBlogIdParser),
  collectiveSupport: z.boolean().default(false),
  common: z.boolean().default(false),
  commonBlogs: z.array(firebaseBlogIdParser),
  description: nullableStringParser,
  gofa: nullableBoolParser,
  hq: nullableStringParser,
  image: nullableUrlStringParser,
  launched: z.boolean().default(false),
  location: nullableStringParser,
  mv: nullableStringParser,
  name: z.string(),
  //Need to find where performances are stored (collection)
  // performanceIDs: z.array(collectiveChannelCreatePerformancesValidation).default([]),
  planetFlyer: nullableStringParser,
  planetImage: nullableUrlStringParser,
  planetName: nullableStringParser,
  planetPosition: z.object({
    x: z.union([z.number(), z.null()]).default(null),
    y: z.union([z.number(), z.null()]).default(null),
  }),
  price: z.union([z.number(), z.null()]).default(null),
  radio: nullableBoolParser,
  smallImage: nullableUrlStringParser,
  sourceCollective: z.union([channelIdParser, z.null()]).default(null),
  //Not validating sourceCollectiveData, which is just the source collective nested in this collective, probably for common collectives
  stripeProductID: stripeProductIdParser,
  subscribers: z.array(channelIdParser).default([]),
  type: nullableStringParser,
  updatedBy: nullableStringParser,
  verified: z.boolean().default(false),
});
export const channelTypeParser = z.enum(CHANNEL_TYPES);

==> currents-api-types-0.0.31.tgz: package/channel/parsers.ts <==
import { z } from 'zod';
import { firestoreListParamsParser } from '../common/parsers/queryParams';
import { nullableBoolParser, nullableStringParser, nullableUrlStringParser } from '../common/parsers';
import { stripeProductIdParser } from '../stripe/parsers';
import { firebaseBlogIdParser } from '../blog/parsers.id';
import { firebaseCollectiveIdParser } from '../collective/parsers.id';
import { firebaseAdminIdParser } from '../collective/parsers.admin';
import { BLOG, CHANNEL_TYPES, COLLECTIVE, MIXSPACE } from './constants';
import { mixspaceIdParser } from '../mixspace/parsers.id';

export const channelListParamsParser = firestoreListParamsParser
  .merge(
    z
      .object({
        adminId: firebaseAdminIdParser,
      })
      .partial()
  )
  .strict();
export type ChannelListParams = z.infer<typeof channelListParamsParser>;
export const channelIdParser = firebaseBlogIdParser.or(firebaseCollectiveIdParser).or(mixspaceIdParser);

// asserted in types
export const channelCompositeIdParser = z.discriminatedUnion('type', [
  z.object({
    type: z.literal(BLOG),
    id: firebaseBlogIdParser,
  }),
  z.object({
    type: z.literal(COLLECTIVE),
    id: firebaseCollectiveIdParser,
  }),
  z.object({
    type: z.literal(MIXSPACE),
    id: mixspaceIdParser,
  }),
]);

export const channelGetOneParamsParser = z.object({
  id: channelIdParser,
});
export type ChannelGetOneParams = z.infer<typeof channelGetOneParamsParser>;
export const blogIdTraitParser = z.object({
  id: firebaseBlogIdParser,
});
export const collectiveChannelCreateInput = z.object({
  MV: nullableStringParser,
  admins: z.array(firebaseBlogIdParser),
  alias: nullableStringParser,
  blogs: z.array(firebaseBlogIdParser),
  collectiveSupport: z.boolean().default(false),
  common: z.boolean().default(false),
  commonBlogs: z.array(firebaseBlogIdParser),
  description: nullableStringParser,
  gofa: nullableBoolParser,
  hq: nullableStringParser,
  image: nullableUrlStringParser,
  launched: z.boolean().default(false),
  location: nullableStringParser,
  mv: nullableStringParser,
  name: z.string(),
  //Need to find where performances are stored (collection)
  // performanceIDs: z.array(collectiveChannelCreatePerformancesValidation).default([]),
  planetFlyer: nullableStringParser,
  planetImage: nullableUrlStringParser,
  planetName: nullableStringParser,
  planetPosition: z.object({
    x: z.union([z.number(), z.null()]).default(null),
    y: z.union([z.number(), z.null()]).default(null),
  }),
  price: z.union([z.number(), z.null()]).default(null),
  radio: nullableBoolParser,
  smallImage: nullableUrlStringParser,
  sourceCollective: channelIdParser,
  //Not validating sourceCollectiveData, which is just the source collective nested in this collective, probably for common collectives
  stripeProductID: stripeProductIdParser,
  subscribers: z.array(channelIdParser).default([]),
  type: nullableStringParser,
  updatedBy: nullableStringParser,
  verified: z.boolean().default(false),
});
export const channelTypeParser = z.enum(CHANNEL_TYPES);
